@@ -1,7 +1,7 @@
 package Perinci::Sub::To::FuncBase;
 
-our $DATE = '2015-12-17'; # DATE
-our $VERSION = '0.69'; # VERSION
+our $DATE = '2015-12-18'; # DATE
+our $VERSION = '0.70'; # VERSION
 
 use 5.010;
 use Log::Any::IfLOG '$log';
@@ -189,7 +189,7 @@ sub gen_doc_section_result {
     my $riresmeta = rimeta($meta->{result});
     my $dres      = $self->{_doc_res};
 
-    my $orig_result_naked = $meta->{_orig_result_naked};
+    my $orig_result_naked = $meta->{_orig_result_naked} // $meta->{result_naked};
 
     $dres->{res_schema} = $meta->{result} ? $meta->{result}{schema} : undef;
     $dres->{res_schema} //= [any => {}];
@@ -224,7 +224,7 @@ Perinci::Sub::To::FuncBase - Base class for Perinci::Sub::To::* function documen
 
 =head1 VERSION
 
-This document describes version 0.69 of Perinci::Sub::To::FuncBase (from Perl distribution Perinci-To-Doc), released on 2015-12-17.
+This document describes version 0.70 of Perinci::Sub::To::FuncBase (from Perl distribution Perinci-To-Doc), released on 2015-12-18.
 
 =for Pod::Coverage .+
 
