@@ -1,7 +1,7 @@
 package Perinci::Sub::To::POD;
 
-our $DATE = '2015-12-17'; # DATE
-our $VERSION = '0.69'; # VERSION
+our $DATE = '2015-12-18'; # DATE
+our $VERSION = '0.70'; # VERSION
 
 use 5.010001;
 use Log::Any::IfLOG '$log';
@@ -61,7 +61,7 @@ sub after_gen_doc {
         if $dres->{summary};
 
     my $examples = $meta->{examples};
-    my $orig_result_naked = $meta->{_orig_result_naked};
+    my $orig_result_naked = $meta->{_orig_result_naked} // $meta->{result_naked};
     my $orig_args_as = $meta->{_orig_args_as} // 'hash';
     my $i = 0;
     my @eg_lines;
@@ -358,7 +358,7 @@ Perinci::Sub::To::POD - Generate POD documentation from Rinci function metadata
 
 =head1 VERSION
 
-This document describes version 0.69 of Perinci::Sub::To::POD (from Perl distribution Perinci-To-Doc), released on 2015-12-17.
+This document describes version 0.70 of Perinci::Sub::To::POD (from Perl distribution Perinci-To-Doc), released on 2015-12-18.
 
 =head1 SYNOPSIS
 
