@@ -1,7 +1,7 @@
 package Perinci::Sub::To::Text;
 
-our $DATE = '2015-12-17'; # DATE
-our $VERSION = '0.69'; # VERSION
+our $DATE = '2015-12-18'; # DATE
+our $VERSION = '0.70'; # VERSION
 
 use 5.010001;
 use Log::Any::IfLOG '$log';
@@ -24,7 +24,7 @@ sub after_gen_doc {
     my $meta  = $self->meta;
     my $dres  = $self->{_doc_res};
 
-    my $orig_result_naked = $meta->{_orig_result_naked};
+    my $orig_result_naked = $meta->{_orig_result_naked} // $meta->{result_naked};
 
     $self->add_doc_lines(
         "+ ".$dres->{name}.$dres->{args_plterm}.' -> '.$dres->{human_ret},
@@ -106,7 +106,7 @@ Perinci::Sub::To::Text - Generate text documentation from Rinci function metadat
 
 =head1 VERSION
 
-This document describes version 0.69 of Perinci::Sub::To::Text (from Perl distribution Perinci-To-Doc), released on 2015-12-17.
+This document describes version 0.70 of Perinci::Sub::To::Text (from Perl distribution Perinci-To-Doc), released on 2015-12-18.
 
 =head1 SYNOPSIS
 
